/***************************************************************
 *
 * Copyright (C) 1990-2007, Condor Team, Computer Sciences Department,
 * University of Wisconsin-Madison, WI.
 * 
 * Licensed under the Apache License, Version 2.0 (the "License"); you
 * may not use this file except in compliance with the License.  You may
 * obtain a copy of the License at
 * 
 *    http://www.apache.org/licenses/LICENSE-2.0
 * 
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 *
 ***************************************************************/

#include "classad/common.h"
#include "classad/debug.h"
#include <stdarg.h>

namespace classad {

int  _except_line_number = -1;
const char *_except_file_name = NULL;

void _classad_except(const char *format, ...)
{
	va_list arguments;

	fprintf(stderr, "**** ClassAd Failure in %s, line %d:\n",
			_except_file_name ? _except_file_name : "<unknown file>",
			_except_line_number);

	va_start(arguments, format);
	vfprintf(stderr, format, arguments);
	va_end(arguments);
	exit(1);
}

} // namespace classad
